﻿using SFML.Audio;
using SFML.System;
using SFML.Window;
using System;

//====================================================
// Описание работы классов и методов исходника на:
// www.interestprograms.ru
// Исходные коды программ и игр
// Автор исходных кодов Клочков Павел
//====================================================

namespace sfml4
{
    class Program
    {
        static void Main()
        {
            var GameProcess = new GameProcess();
            GameProcess.Run();
        }
    }

    class GameProcess
    {
        private readonly Sound sound = new Sound();
        private readonly Window2D window2D = new Window2D();
        private readonly Rocket rocket = new Rocket();
        private readonly Asteroid asteroid = new Asteroid();

        public GameProcess()
        {
            window2D.MouseButtonReleased += Window2D_MouseButtonReleased;
            window2D.KeyReleased += Window2D_KeyReleased;

            rocket.ExplosionEvent += Rocket_ExplosionEvent;

            var soundBuffer = new SoundBuffer(Resource.explosion);
            sound.SoundBuffer = soundBuffer;

        }

        private void Rocket_ExplosionEvent(object sender, EventArgs e)
        {
            sound.Play();
            asteroid.StartExplosion();
        }

        private void Window2D_KeyReleased(object sender, KeyEventArgs e)
        {
            // При нажатии любой клавиши окно закрывается
            ((SFML.Graphics.RenderWindow)sender).Close();
        }

        private void Window2D_MouseButtonReleased(object sender, MouseButtonEventArgs e)
        {
            // Отправка новых координат объекту ракеты.
            // Для расчёта нового направления движения.
            rocket.ComputeDirection(new Vector2f(e.X, e.Y));

            // Изменение позиции астероида.
            asteroid.Position(new Vector2f(e.X, e.Y));
        }

        // Запуск игры
        public void Run()
        {

            while (window2D.IsOpen == true)
            {
                // Обработка очереди событий
                window2D.DispatchEvents();

                // Самым первым рисуем фон
                window2D.DrawBG();

                // Затем ракету
                window2D.Draw(rocket.Draw());

                // Астероид должен перекрывать ракету
                asteroid.Draw(window2D);

                // Показываем кадр всего что подготовлено
                window2D.Display();
            }
        }


    }
}
